ValueType

Struct ValueType 

pub struct ValueType<T>
where T: Clone + PartialEq,
{ /* private fields */ }
Value type like a memory undo/redo type. Rundo will clone its origin value as a backup, so Clone must be implemented. Be careful use it for struct or other big size type, OpType is design for this scenario, or you must implment your custrom rundo type.